@@ -1,10 +1,13 @@
-// #![allow(unused)] // silence unused warnings while exploring (to comment out)
+#![allow(unused)] // silence unused warnings while exploring (to comment out)
 
 mod app_error;
 mod cmd;
 mod kdd;
 mod utils;
-mod yutils;
+
+#[cfg(test)]
+#[path = "./_test/test_utils.rs"]
+mod test_utils;
 
 use crate::cmd::cmd_run;
 
